==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ConnectionMonitorHttpConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.HTTPConfigurationMethod
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes the HTTP configuration.
 * @property method The HTTP method to use.
 * @property path The path component of the URI. For instance, "/dir1/dir2".
 * @property port The port to connect to.
 * @property preferHTTPS Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit.
 * @property requestHeaders The HTTP headers to transmit with the request.
 * @property validStatusCodeRanges HTTP status codes to consider successful. For instance, "2xx,301-304,418".
 */
public data class ConnectionMonitorHttpConfigurationArgs(
    public val method: Output<Either<String, HTTPConfigurationMethod>>? = null,
    public val path: Output<String>? = null,
    public val port: Output<Int>? = null,
    public val preferHTTPS: Output<Boolean>? = null,
    public val requestHeaders: Output<List<HTTPHeaderArgs>>? = null,
    public val validStatusCodeRanges: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs =
        com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs.builder()
            .method(
                method?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .path(path?.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 }))
            .preferHTTPS(preferHTTPS?.applyValue({ args0 -> args0 }))
            .requestHeaders(
                requestHeaders?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .validStatusCodeRanges(
                validStatusCodeRanges?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectionMonitorHttpConfigurationArgs].
 */
@PulumiTagMarker
public class ConnectionMonitorHttpConfigurationArgsBuilder internal constructor() {
    private var method: Output<Either<String, HTTPConfigurationMethod>>? = null

    private var path: Output<String>? = null

    private var port: Output<Int>? = null

    private var preferHTTPS: Output<Boolean>? = null

    private var requestHeaders: Output<List<HTTPHeaderArgs>>? = null

    private var validStatusCodeRanges: Output<List<String>>? = null

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("qewdwlyxegrcyybo")
    public suspend fun method(`value`: Output<Either<String, HTTPConfigurationMethod>>) {
        this.method = value
    }

    /**
     * @param value The path component of the URI. For instance, "/dir1/dir2".
     */
    @JvmName("wyaehdnjkjrbywcf")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The port to connect to.
     */
    @JvmName("qboryyomjqrlsvjl")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit.
     */
    @JvmName("mklyveogjeblrmvt")
    public suspend fun preferHTTPS(`value`: Output<Boolean>) {
        this.preferHTTPS = value
    }

    /**
     * @param value The HTTP headers to transmit with the request.
     */
    @JvmName("jqanrnkandwbncek")
    public suspend fun requestHeaders(`value`: Output<List<HTTPHeaderArgs>>) {
        this.requestHeaders = value
    }

    @JvmName("wmtordkgvhpydnmd")
    public suspend fun requestHeaders(vararg values: Output<HTTPHeaderArgs>) {
        this.requestHeaders = Output.all(values.asList())
    }

    /**
     * @param values The HTTP headers to transmit with the request.
     */
    @JvmName("efceymevswxfuqax")
    public suspend fun requestHeaders(values: List<Output<HTTPHeaderArgs>>) {
        this.requestHeaders = Output.all(values)
    }

    /**
     * @param value HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("cvecfchpcgvlmheq")
    public suspend fun validStatusCodeRanges(`value`: Output<List<String>>) {
        this.validStatusCodeRanges = value
    }

    @JvmName("lxpmyqoqumrbevho")
    public suspend fun validStatusCodeRanges(vararg values: Output<String>) {
        this.validStatusCodeRanges = Output.all(values.asList())
    }

    /**
     * @param values HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("nyrxlahnilurvfhh")
    public suspend fun validStatusCodeRanges(values: List<Output<String>>) {
        this.validStatusCodeRanges = Output.all(values)
    }

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("ytypmyqytmnuioov")
    public suspend fun method(`value`: Either<String, HTTPConfigurationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.method = mapped
    }

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("bvfxqxwismsgcigf")
    public fun method(`value`: String) {
        val toBeMapped = Either.ofLeft<String, HTTPConfigurationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.method = mapped
    }

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("nhkfcqcfldiffwdf")
    public fun method(`value`: HTTPConfigurationMethod) {
        val toBeMapped = Either.ofRight<String, HTTPConfigurationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.method = mapped
    }

    /**
     * @param value The path component of the URI. For instance, "/dir1/dir2".
     */
    @JvmName("vrnpudmaviyiojcs")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value The port to connect to.
     */
    @JvmName("vmxkrgbaatktxqbq")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit.
     */
    @JvmName("ilsyngxbvvtghncm")
    public suspend fun preferHTTPS(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preferHTTPS = mapped
    }

    /**
     * @param value The HTTP headers to transmit with the request.
     */
    @JvmName("lkckoujpikkjqbbb")
    public suspend fun requestHeaders(`value`: List<HTTPHeaderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestHeaders = mapped
    }

    /**
     * @param argument The HTTP headers to transmit with the request.
     */
    @JvmName("xxhdlvbivussgoew")
    public suspend fun requestHeaders(argument: List<suspend HTTPHeaderArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { HTTPHeaderArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.requestHeaders = mapped
    }

    /**
     * @param argument The HTTP headers to transmit with the request.
     */
    @JvmName("cyeitffcamgbuhyt")
    public suspend fun requestHeaders(vararg argument: suspend HTTPHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { HTTPHeaderArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.requestHeaders = mapped
    }

    /**
     * @param argument The HTTP headers to transmit with the request.
     */
    @JvmName("xrjfrmciovrvswhu")
    public suspend fun requestHeaders(argument: suspend HTTPHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HTTPHeaderArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.requestHeaders = mapped
    }

    /**
     * @param values The HTTP headers to transmit with the request.
     */
    @JvmName("ysmlxdsolfqjjkly")
    public suspend fun requestHeaders(vararg values: HTTPHeaderArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requestHeaders = mapped
    }

    /**
     * @param value HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("tgcbpaytifpdjrua")
    public suspend fun validStatusCodeRanges(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validStatusCodeRanges = mapped
    }

    /**
     * @param values HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("yyroyopbkqfxmqeu")
    public suspend fun validStatusCodeRanges(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validStatusCodeRanges = mapped
    }

    internal fun build(): ConnectionMonitorHttpConfigurationArgs =
        ConnectionMonitorHttpConfigurationArgs(
            method = method,
            path = path,
            port = port,
            preferHTTPS = preferHTTPS,
            requestHeaders = requestHeaders,
            validStatusCodeRanges = validStatusCodeRanges,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ConnectionMonitorHttpConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.HTTPConfigurationMethod
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes the HTTP configuration.
 * @property method The HTTP method to use.
 * @property path The path component of the URI. For instance, "/dir1/dir2".
 * @property port The port to connect to.
 * @property preferHTTPS Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit.
 * @property requestHeaders The HTTP headers to transmit with the request.
 * @property validStatusCodeRanges HTTP status codes to consider successful. For instance, "2xx,301-304,418".
 */
public data class ConnectionMonitorHttpConfigurationArgs(
    public val method: Output<Either<String, HTTPConfigurationMethod>>? = null,
    public val path: Output<String>? = null,
    public val port: Output<Int>? = null,
    public val preferHTTPS: Output<Boolean>? = null,
    public val requestHeaders: Output<List<HTTPHeaderArgs>>? = null,
    public val validStatusCodeRanges: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs =
        com.pulumi.azurenative.network.inputs.ConnectionMonitorHttpConfigurationArgs.builder()
            .method(
                method?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .path(path?.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 }))
            .preferHTTPS(preferHTTPS?.applyValue({ args0 -> args0 }))
            .requestHeaders(
                requestHeaders?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .validStatusCodeRanges(
                validStatusCodeRanges?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectionMonitorHttpConfigurationArgs].
 */
@PulumiTagMarker
public class ConnectionMonitorHttpConfigurationArgsBuilder internal constructor() {
    private var method: Output<Either<String, HTTPConfigurationMethod>>? = null

    private var path: Output<String>? = null

    private var port: Output<Int>? = null

    private var preferHTTPS: Output<Boolean>? = null

    private var requestHeaders: Output<List<HTTPHeaderArgs>>? = null

    private var validStatusCodeRanges: Output<List<String>>? = null

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("bpqhspqvvrtwowds")
    public suspend fun method(`value`: Output<Either<String, HTTPConfigurationMethod>>) {
        this.method = value
    }

    /**
     * @param value The path component of the URI. For instance, "/dir1/dir2".
     */
    @JvmName("janssnpducarpwrv")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The port to connect to.
     */
    @JvmName("ldlofssjpjefovbn")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit.
     */
    @JvmName("avgqlhbegcpixsrk")
    public suspend fun preferHTTPS(`value`: Output<Boolean>) {
        this.preferHTTPS = value
    }

    /**
     * @param value The HTTP headers to transmit with the request.
     */
    @JvmName("nrcqspvjhhhjkjcq")
    public suspend fun requestHeaders(`value`: Output<List<HTTPHeaderArgs>>) {
        this.requestHeaders = value
    }

    @JvmName("eyysxombosihkuky")
    public suspend fun requestHeaders(vararg values: Output<HTTPHeaderArgs>) {
        this.requestHeaders = Output.all(values.asList())
    }

    /**
     * @param values The HTTP headers to transmit with the request.
     */
    @JvmName("ocbhxgovfyvignde")
    public suspend fun requestHeaders(values: List<Output<HTTPHeaderArgs>>) {
        this.requestHeaders = Output.all(values)
    }

    /**
     * @param value HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("eipjgpbxlvkmqtac")
    public suspend fun validStatusCodeRanges(`value`: Output<List<String>>) {
        this.validStatusCodeRanges = value
    }

    @JvmName("tbmcwajktmsspebf")
    public suspend fun validStatusCodeRanges(vararg values: Output<String>) {
        this.validStatusCodeRanges = Output.all(values.asList())
    }

    /**
     * @param values HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("jjvnwardtruvqxpl")
    public suspend fun validStatusCodeRanges(values: List<Output<String>>) {
        this.validStatusCodeRanges = Output.all(values)
    }

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("dauvopwmtbkftilc")
    public suspend fun method(`value`: Either<String, HTTPConfigurationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.method = mapped
    }

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("wcddeybpojrktfkh")
    public fun method(`value`: String) {
        val toBeMapped = Either.ofLeft<String, HTTPConfigurationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.method = mapped
    }

    /**
     * @param value The HTTP method to use.
     */
    @JvmName("nrruhojnqflowrck")
    public fun method(`value`: HTTPConfigurationMethod) {
        val toBeMapped = Either.ofRight<String, HTTPConfigurationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.method = mapped
    }

    /**
     * @param value The path component of the URI. For instance, "/dir1/dir2".
     */
    @JvmName("uuowxlymdhwnhddt")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value The port to connect to.
     */
    @JvmName("ynfdexuvfexfqswj")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit.
     */
    @JvmName("kseexpfbkanndmet")
    public suspend fun preferHTTPS(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preferHTTPS = mapped
    }

    /**
     * @param value The HTTP headers to transmit with the request.
     */
    @JvmName("uugejcqgerdhvkdk")
    public suspend fun requestHeaders(`value`: List<HTTPHeaderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestHeaders = mapped
    }

    /**
     * @param argument The HTTP headers to transmit with the request.
     */
    @JvmName("pdeqtjjomrlmoxfp")
    public suspend fun requestHeaders(argument: List<suspend HTTPHeaderArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { HTTPHeaderArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.requestHeaders = mapped
    }

    /**
     * @param argument The HTTP headers to transmit with the request.
     */
    @JvmName("udankndbsshoejec")
    public suspend fun requestHeaders(vararg argument: suspend HTTPHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { HTTPHeaderArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.requestHeaders = mapped
    }

    /**
     * @param argument The HTTP headers to transmit with the request.
     */
    @JvmName("qunigtnykhjcjnqs")
    public suspend fun requestHeaders(argument: suspend HTTPHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HTTPHeaderArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.requestHeaders = mapped
    }

    /**
     * @param values The HTTP headers to transmit with the request.
     */
    @JvmName("alrymysauxuwgkmw")
    public suspend fun requestHeaders(vararg values: HTTPHeaderArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requestHeaders = mapped
    }

    /**
     * @param value HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("wdrmgavygdbkkyqs")
    public suspend fun validStatusCodeRanges(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validStatusCodeRanges = mapped
    }

    /**
     * @param values HTTP status codes to consider successful. For instance, "2xx,301-304,418".
     */
    @JvmName("bclrunqgxfljiqxm")
    public suspend fun validStatusCodeRanges(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validStatusCodeRanges = mapped
    }

    internal fun build(): ConnectionMonitorHttpConfigurationArgs =
        ConnectionMonitorHttpConfigurationArgs(
            method = method,
            path = path,
            port = port,
            preferHTTPS = preferHTTPS,
            requestHeaders = requestHeaders,
            validStatusCodeRanges = validStatusCodeRanges,
        )
}
